pub struct TxSenderConfig {
pub network: Network,
pub secret_key: SecretKey,
pub private_da_key: Option<SecretKey>,
pub postgres: TxSenderPostgresConfig,
pub bitcoin_rpc: TxSenderBitcoinRpcConfig,
pub mempool: MempoolConfig,
pub limits: TxSenderLimits,
pub finality_depth: u32,
pub poll_delay_ms: u64,
pub include_unsafe: bool,
pub jsonrpc: Option<TxSenderJsonRpcConfig>,
}Expand description
Configuration for running the tx-sender service standalone.
Fields
network: Networksecret_key: SecretKeyTaproot signing key used by tx-sender.
In clementine_core usage this is derived from BridgeConfig.secret_key.
In standalone usage it is sourced from env SECRET_KEY.
private_da_key: Option<SecretKey>Optional Citrea DA blob signing key.
If not provided, tx-sender falls back to secret_key for Citrea blob signing.
postgres: TxSenderPostgresConfigbitcoin_rpc: TxSenderBitcoinRpcConfigmempool: MempoolConfiglimits: TxSenderLimitsfinality_depth: u32How many confirmations are required before tx-sender treats an observation as final.
The chain tip has 1 confirmation. Minimum value should be 1.
poll_delay_ms: u64Poll delay for the txsender loop if txsender is used as standalone, in milliseconds.
If not provided, defaults to 30 seconds.
include_unsafe: boolWhether to use unsafe utxos for funding new txs. An utxo is unsafe it belongs to a tx with at least one non wallet input, if it belongs to a tx that was rbf replaced.
jsonrpc: Option<TxSenderJsonRpcConfig>Optional JSON-RPC configuration, will not be used if json-rpc feature is not .
Implementations